/* GtkWindowPeer.java -- Implements WindowPeer with GTK
   Copyright (C) 1998, 1999 Free Software Foundation, Inc.

This file is part of the peer AWT libraries of GNU Classpath.

This library is free software; you can redistribute it and/or modify
it under the terms of the GNU Library General Public License as published 
by the Free Software Foundation, either version 2 of the License, or
(at your option) any later verion.

This library is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Library General Public License for more details.

You should have received a copy of the GNU Library General Public License
along with this library; if not, write to the Free Software Foundation
Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307 USA. */


package gnu.java.awt.peer.gtk;
import java.awt.peer.*;
import java.awt.*;

public class GtkWindowPeer extends GtkContainerPeer
  implements WindowPeer
{
  static protected final int GTK_WINDOW_TOPLEVEL = 0;
  static protected final int GTK_WINDOW_DIALOG = 1;
  static protected final int GTK_WINDOW_POPUP = 2;

  native void create (int type);

  void create ()
  {
    create (GTK_WINDOW_POPUP);
  }

  native void connectHooks ();

  public GtkWindowPeer (Window window)
  {
    super (window);

    Dimension d = window.getSize ();
    setBounds (0, 0, d.width, d.height);
  }

  public void getArgs (Component component, GtkArgList args)
  {
    args.add ("visible", component.isVisible ());
    args.add ("sensitive", component.isEnabled ());
  }
  
  native public void toBack ();
  native public void toFront ();

  native public void setBounds (int x, int y, int width, int height);

  public void setTitle (String title)
  {
    set ("title", title);
  }

  native public void setResizable (boolean r);

  native public void setMenuBarPeer (GtkMenuBarPeer bar);

  public void setMenuBar (MenuBar bar)
  {
    if (bar == null)
      setMenuBarPeer (null);
    else
      setMenuBarPeer ((GtkMenuBarPeer) bar.getPeer ());
  }

    static boolean post_flag = false;

    /* mrl wjw  protected */  void postConfigureEvent (int x, int y, int width, int height,
				     int top, int left, int bottom, int right)
  {
      // synchronized(java.awt.mrl_sync.sync_obj) { // wjw mrl

	  try {
	      if (post_flag == false) {
		    Thread.sleep(2000);
            System.out.println("first postConfigureEvent()");
		    post_flag = true;
	      }
	        } catch (Exception e) {System.out.println("broken22 " + e);}

	  // System.out.println("ENTER postConfigureEvent()");

    /* 
       If our borders change (which often happens when we opaque resize),
       we need to make sure that a new layout will happen, since Sun
       forgets to handle this case.
    */
    if (insets1.top != top
	|| insets1.left != left
	|| insets1.bottom != bottom
	|| insets1.right != right)
      {
	//System.out.println ("invalidating");
	awtComponent.invalidate ();
      }
    
    insets1.top = top;
    insets1.left = left;
    insets1.bottom = bottom;
    insets1.right = right;

    awtComponent.setBounds (x, y, width, height);
    awtComponent.validate ();
   
    //System.out.println("EXIT postConfigureEvent()");

    //   } // end of mrl_sync
  }
  
  native public void setVisible (boolean b);
}

